@@ -125,9 +125,7 @@ def connect_pymssql(host, port=None, username=None, password=None, database=None
     )
     if sniff_only:
         return ConnectStrategy(opener=pymssql.connect, open_args=params)
-    conn = pymssql.connect(
-        **params
-    )
+    conn = pymssql.connect(**params)
     if not for_write:
         _set_conn_read_only(conn)
     conn._flavor = "mssql"
@@ -149,7 +147,7 @@ def connect_psycopg2(host, port=None, username=None, password=None, database=Non
     params = dict(dsn=pg_args_str, **kwargs)
     if sniff_only:
         return ConnectStrategy(opener=psycopg2.connect, open_args=params)
-    conn = psycopg2.connect(params)
+    conn = psycopg2.connect(**params)
     if autocommit:
         conn.set_isolation_level(psycopg2.extensions.ISOLATION_LEVEL_AUTOCOMMIT)
     if not for_write:
